<?php

/*
|--------------------------------------------------------------------------
| Application Routes
|--------------------------------------------------------------------------
|
| Here is where you can register all of the routes for an application.
| It is a breeze. Simply tell Lumen the URIs it should respond to
| and give it the Closure to call when that URI is requested.
|
*/

$api = app('Dingo\Api\Routing\Router');

$api->version('v1', [
    'namespace' => 'App\Http\Controllers',
], function ($api) {
    //百度编辑器
    $api->get('ueupload', 'UeditorController@index');
    $api->post('ueupload', 'UeditorController@index');

    $api->group(['middleware' => 'jwt.chxq_auth'], function ($api) {
        $api->get('user', 'UserController@index');

        //上传
        $api->post('upload', 'UploadController@uploadImage');
        $api->post('multi_upload', 'UploadController@uploadImages');
        $api->post('upload/mp3', 'UploadController@uploadMp3');

        //自提点列表
        $api->get('/pickupNode/index', 'ConfigPickupNodeController@index');
        //自提点新建
        $api->post('/pickupNode/create', 'ConfigPickupNodeController@create');
        //自提点编辑
        $api->put('/pickupNode/edit', 'ConfigPickupNodeController@edit');
        //查看自提点
        $api->get('/pickupNode/view', 'ConfigPickupNodeController@view');

        //自提点分组列表
        $api->get('/pickupGroup/index', 'ConfigPickupGroupController@index');
        //自提点分组新增
        $api->post('/pickupGroup/create', 'ConfigPickupGroupController@create');

        // 储存方式列表
        $api->get('/storeType/index', 'StoreTypeController@index');

        //获取省市区
        $api->get('/configProvince/province', 'ConfigProvinceController@province');

        //城市列表
        $api->get('/cityManagement/lists', 'ConfigCityManagementController@lists');
        //编辑城市
        $api->put('/cityManagement/edit', 'ConfigCityManagementController@edit');
        //删除城市
        $api->delete('/cityManagement/delete', 'ConfigCityManagementController@delete');
        //新增城市
        $api->post('/cityManagement/create', 'ConfigCityManagementController@create');

        //消息规则列表
        $api->get('message', 'MessageRuleController@index');
        //创建消息规则
        $api->post('message', 'MessageRuleController@create');
        //编辑消息规则
        $api->put('message', 'MessageRuleController@update');
        //消息规则详情
        $api->get('message/detail', 'MessageRuleController@detail');
        //发送消息规则
        $api->put('message/send', 'MessageRuleController@send');
        //隐藏消息规则
        $api->put('message/hide', 'MessageRuleController@hide');

    });
    //配置文件
    $api->get('/config', 'ConfigController@index');
});

$api->version('v1', [
    'namespace' => 'App\Http\Controllers\V2',
], function ($api) {

    $api->group([
        'prefix' => 'v2'
    ], function ($api) {
        $api->group(['middleware' => 'jwt.chxq_auth'], function ($api) {
            //banner列表
            $api->get('/bannerSet/lists', 'BannerController@lists');
            //新增banner
            $api->post('/bannerSet', 'BannerController@bannerSet');
            //编辑banner
            $api->put('/bannerSet/edit', 'BannerController@edit');
            //删除banner
            $api->delete('/bannerSet/delete', 'BannerController@bannerDelete');
            //修改banner状态
            $api->put('/bannerSet/editStatus', 'BannerController@editStatus');
            //活动列表
            $api->get('activitiesIndex', 'ActivitiesController@index');
            //活动添加
            $api->post('activitiesCreate', 'ActivitiesController@create');
            //活动编辑
            $api->put('activitiesEdit', 'ActivitiesController@edit');
            //活动详情
            $api->get('activitiesView', 'ActivitiesController@view');

            //星球新闻列表
            $api->get('/starNews/lists', 'StarNewsController@index');
            //新增星球新闻
            $api->post('/starNews/create', 'StarNewsController@create');
            //编辑星球新闻
            $api->put('/starNews/create', 'StarNewsController@edit');
            //修改星球新闻状态
            $api->put('/starNews/editStatus', 'StarNewsController@editStatus');
            //删除星球新闻
            $api->delete('/starNews/delete', 'StarNewsController@delete');

            //平台内容列表
            $api->get('/platformContent/lists', 'PlatformContentController@index');
            //新增平台内容
            $api->post('/platformContent/create', 'PlatformContentController@create');
            //编辑平台内容
            $api->put('/platformContent/create', 'PlatformContentController@edit');
        });
    });
});